function a0_0x242e(){const _0x414278=['245139ETacpa','150Povbpm','\x20|\x20','start','/tracker','127192eVhgJG','internalId','500825hbDHem','active','captionChanged','assign','936040SkqrTj','com.finkit.manictime.tracker','28jKuxMz','windowActivated','129776tNCpzP','180YJMWEk','connect','publishApplication','message','clientActivated','windowList','3523370RvazGO','com.finkit.manictime','timeout','53123bEoDel'];a0_0x242e=function(){return _0x414278;};return a0_0x242e();}const a0_0x2c721f=a0_0xa6fc;(function(_0x4e1d12,_0x5930fd){const _0x202060=a0_0xa6fc,_0x1edcbf=_0x4e1d12();while(!![]){try{const _0x311f2c=-parseInt(_0x202060(0x122))/0x1+-parseInt(_0x202060(0x12a))/0x2+parseInt(_0x202060(0x11b))/0x3*(parseInt(_0x202060(0x128))/0x4)+parseInt(_0x202060(0x126))/0x5+-parseInt(_0x202060(0x11c))/0x6*(-parseInt(_0x202060(0x11a))/0x7)+parseInt(_0x202060(0x120))/0x8*(-parseInt(_0x202060(0x12b))/0x9)+parseInt(_0x202060(0x117))/0xa;if(_0x311f2c===_0x5930fd)break;else _0x1edcbf['push'](_0x1edcbf['shift']());}catch(_0x32223e){_0x1edcbf['push'](_0x1edcbf['shift']());}}}(a0_0x242e,0x65f20));function a0_0xa6fc(_0x33c571,_0xd1d584){_0x33c571=_0x33c571-0x116;const _0x242ec8=a0_0x242e();let _0xa6fcc1=_0x242ec8[_0x33c571];return _0xa6fcc1;}function publishWindowApplication(_0x17c716){const _0x5deb0e=a0_0xa6fc;if(!_0x17c716)return;const {caption:_0x24c3ae,resourceClass:_0x12caea,resourceName:_0x5b3333,pid:_0x3f155c,windowId:_0x5546ab}=_0x17c716;print(_0x24c3ae+_0x5deb0e(0x11d)+_0x12caea+_0x5deb0e(0x11d)+_0x5b3333+_0x5deb0e(0x11d)+_0x3f155c+_0x5deb0e(0x11d)+_0x5546ab);try{callDBus(_0x5deb0e(0x118),'/tracker','com.finkit.manictime.tracker',_0x5deb0e(0x12d),_0x24c3ae,_0x12caea,_0x5b3333,_0x3f155c);}catch(_0x5eba9e){print(_0x5eba9e[_0x5deb0e(0x12e)]);}}function publishMouseMove(_0x35d7ef){const _0x59e237=a0_0xa6fc;if(!_0x35d7ef)return;try{callDBus(_0x59e237(0x118),_0x59e237(0x11f),_0x59e237(0x127),'publishMouseMove',_0x35d7ef['x'],_0x35d7ef['y']);}catch(_0xbf233){print(_0xbf233[_0x59e237(0x12e)]);}}let lastMousePosition={'x':0x0,'y':0x0};function checkMouseMove(){const _0x2f84a8=a0_0xa6fc,_0x20aca4=workspace['cursorPos'];(_0x20aca4['x']!==lastMousePosition['x']||_0x20aca4['y']!==lastMousePosition['y'])&&(Object[_0x2f84a8(0x125)](lastMousePosition,_0x20aca4),publishMouseMove(_0x20aca4));}let windowCaptionChangedSubscriptions={},handleWindowActive=function(_0x43d515){const _0x166082=a0_0xa6fc;if(_0x43d515===null)return;!(_0x43d515[_0x166082(0x121)]in windowCaptionChangedSubscriptions)&&(windowCaptionChangedSubscriptions[_0x43d515[_0x166082(0x121)]]=!![],_0x43d515[_0x166082(0x124)][_0x166082(0x12c)](function(){const _0x1df5c9=_0x166082;_0x43d515[_0x1df5c9(0x123)]&&publishWindowApplication(_0x43d515);})),publishWindowApplication(_0x43d515);};checkMouseMove();const myTimer=new QTimer();myTimer[a0_0x2c721f(0x119)][a0_0x2c721f(0x12c)](checkMouseMove),myTimer[a0_0x2c721f(0x11e)](0x3e8);try{if(typeof workspace['clientActivated']!=='undefined'){workspace[a0_0x2c721f(0x12f)]['connect'](handleWindowActive);for(const client of workspace['clientList']()){if(client[a0_0x2c721f(0x123)]){handleWindowActive(client);break;}}}}catch(a0_0x937d53){print(a0_0x937d53[a0_0x2c721f(0x12e)]);}try{if(typeof workspace[a0_0x2c721f(0x129)]!=='undefined'){workspace[a0_0x2c721f(0x129)][a0_0x2c721f(0x12c)](handleWindowActive);for(const window of workspace[a0_0x2c721f(0x116)]()){if(window[a0_0x2c721f(0x123)]){handleWindowActive(window);break;}}}}catch(a0_0x17f902){print(a0_0x17f902[a0_0x2c721f(0x12e)]);}